!!! note
    All of the custom [Input][textual.widgets.Input] widgets have their [Changed][textual.widgets.Input.Changed], [Submitted][textual.widgets.Input.Submitted] and [Blurred][textual.widgets.Input.Blurred] messages disabled by default.

!!! info
    All inputs have an `AbstractInput.action_adjust_time` action which allows the user to adjust the value depending on the keyboard cursor location.
    This spinbox functionality can be accessed through clicking then dragging up/down, mouse wheel usage and up/down arrows. 

---

::: textual_timepiece.pickers.DateInput

---

::: textual_timepiece.pickers.TimeInput

---

::: textual_timepiece.pickers.DurationInput

---

::: textual_timepiece.pickers.DateTimeInput
